@@ -147,19 +147,19 @@ class AlgorithmEstimator(EstimatorBase):
         self.algorithm_arn = algorithm_arn
         super(AlgorithmEstimator, self).__init__(
             role,
-            instance_count,
-            instance_type,
-            volume_size,
-            volume_kms_key,
-            max_run,
-            input_mode,
-            output_path,
-            output_kms_key,
-            base_job_name,
-            sagemaker_session,
-            tags,
-            subnets,
-            security_group_ids,
+            instance_count=instance_count,
+            instance_type=instance_type,
+            volume_size=volume_size,
+            volume_kms_key=volume_kms_key,
+            max_run=max_run,
+            input_mode=input_mode,
+            output_path=output_path,
+            output_kms_key=output_kms_key,
+            base_job_name=base_job_name,
+            sagemaker_session=sagemaker_session,
+            tags=tags,
+            subnets=subnets,
+            security_group_ids=security_group_ids,
             model_uri=model_uri,
             model_channel_name=model_channel_name,
             metric_definitions=metric_definitions,
