@@ -13,6 +13,8 @@
 """Placeholder docstring"""
 from __future__ import absolute_import
 
+from typing import Union, Optional
+
 from sagemaker import image_uris
 from sagemaker.amazon.amazon_estimator import AmazonAlgorithmEstimatorBase
 from sagemaker.amazon.hyperparameter import Hyperparameter as hp  # noqa
@@ -20,7 +22,9 @@ from sagemaker.amazon.validation import ge, le, isin
 from sagemaker.predictor import Predictor
 from sagemaker.model import Model
 from sagemaker.session import Session
+from sagemaker.utils import pop_out_unused_kwarg
 from sagemaker.vpc_utils import VPC_CONFIG_DEFAULT
+from sagemaker.workflow.entities import PipelineVariable
 
 
 def _list_check_subset(valid_super_list):
@@ -344,7 +348,13 @@ class Object2VecModel(Model):
     Predictor that calculates anomaly scores for datapoints.
     """
 
-    def __init__(self, model_data, role, sagemaker_session=None, **kwargs):
+    def __init__(
+        self,
+        model_data: Union[str, PipelineVariable],
+        role: str,
+        sagemaker_session: Optional[Session] = None,
+        **kwargs
+    ):
         """Initialization for Object2VecModel class.
 
         Args:
@@ -368,6 +378,8 @@ class Object2VecModel(Model):
             sagemaker_session.boto_region_name,
             version=Object2Vec.repo_version,
         )
+        pop_out_unused_kwarg("predictor_cls", kwargs, Predictor.__name__)
+        pop_out_unused_kwarg("image_uri", kwargs, image_uri)
         super(Object2VecModel, self).__init__(
             image_uri,
             model_data,
