@@ -14,6 +14,7 @@
 from __future__ import absolute_import
 
 import os
+from typing import Union, Optional
 
 from six.moves.urllib.parse import urlparse
 
@@ -22,6 +23,8 @@ from sagemaker import local, s3
 from sagemaker.deprecations import removed_kwargs
 from sagemaker.model import Model
 from sagemaker.session import Session
+from sagemaker.utils import pop_out_unused_kwarg
+from sagemaker.workflow.entities import PipelineVariable
 
 MULTI_MODEL_CONTAINER_MODE = "MultiModel"
 
@@ -34,12 +37,12 @@ class MultiDataModel(Model):
 
     def __init__(
         self,
-        name,
-        model_data_prefix,
-        model=None,
-        image_uri=None,
-        role=None,
-        sagemaker_session=None,
+        name: str,
+        model_data_prefix: str,
+        model: Optional[Model] = None,
+        image_uri: Optional[Union[str, PipelineVariable]] = None,
+        role: Optional[str] = None,
+        sagemaker_session: Optional[Session] = None,
         **kwargs,
     ):
         """Initialize a ``MultiDataModel``.
@@ -106,6 +109,7 @@ class MultiDataModel(Model):
 
         # Set the ``Model`` parameters if the model parameter is not specified
         if not self.model:
+            pop_out_unused_kwarg("model_data", kwargs, self.model_data_prefix)
             super(MultiDataModel, self).__init__(
                 image_uri,
                 self.model_data_prefix,
@@ -115,7 +119,9 @@ class MultiDataModel(Model):
                 **kwargs,
             )
 
-    def prepare_container_def(self, instance_type=None, accelerator_type=None):
+    def prepare_container_def(
+        self, instance_type=None, accelerator_type=None, serverless_inference_config=None
+    ):
         """Return a container definition set.
 
         Definition set includes MultiModel mode, model data and other parameters
