@@ -13,15 +13,19 @@
 """Placeholder docstring"""
 from __future__ import absolute_import
 
-from typing import Optional, Dict
+from typing import Optional, Dict, List, Union
 
 import sagemaker
-from sagemaker import ModelMetrics
+from sagemaker import ModelMetrics, Model
 from sagemaker.drift_check_baselines import DriftCheckBaselines
 from sagemaker.metadata_properties import MetadataProperties
 from sagemaker.session import Session
-from sagemaker.utils import name_from_image
+from sagemaker.utils import (
+    name_from_image,
+    update_container_with_inference_params,
+)
 from sagemaker.transformer import Transformer
+from sagemaker.workflow.entities import PipelineVariable
 from sagemaker.workflow.pipeline_context import runnable_by_pipeline
 
 
@@ -33,13 +37,13 @@ class PipelineModel(object):
 
     def __init__(
         self,
-        models,
-        role,
-        predictor_cls=None,
-        name=None,
-        vpc_config=None,
-        sagemaker_session=None,
-        enable_network_isolation=False,
+        models: List[Model],
+        role: str,
+        predictor_cls: Optional[callable] = None,
+        name: Optional[str] = None,
+        vpc_config: Optional[Dict[str, List[Union[str, PipelineVariable]]]] = None,
+        sagemaker_session: Optional[Session] = None,
+        enable_network_isolation: Union[bool, PipelineVariable] = False,
     ):
         """Initialize a SageMaker `Model` instance.
 
@@ -264,21 +268,27 @@ class PipelineModel(object):
     @runnable_by_pipeline
     def register(
         self,
-        content_types: list,
-        response_types: list,
-        inference_instances: Optional[list] = None,
-        transform_instances: Optional[list] = None,
-        model_package_name: Optional[str] = None,
-        model_package_group_name: Optional[str] = None,
-        image_uri: Optional[str] = None,
+        content_types: List[Union[str, PipelineVariable]],
+        response_types: List[Union[str, PipelineVariable]],
+        inference_instances: Optional[List[Union[str, PipelineVariable]]] = None,
+        transform_instances: Optional[List[Union[str, PipelineVariable]]] = None,
+        model_package_name: Optional[Union[str, PipelineVariable]] = None,
+        model_package_group_name: Optional[Union[str, PipelineVariable]] = None,
+        image_uri: Optional[Union[str, PipelineVariable]] = None,
         model_metrics: Optional[ModelMetrics] = None,
         metadata_properties: Optional[MetadataProperties] = None,
         marketplace_cert: bool = False,
-        approval_status: Optional[str] = None,
+        approval_status: Optional[Union[str, PipelineVariable]] = None,
         description: Optional[str] = None,
         drift_check_baselines: Optional[DriftCheckBaselines] = None,
-        customer_metadata_properties: Optional[Dict[str, str]] = None,
-        domain: Optional[str] = None,
+        customer_metadata_properties: Optional[Dict[str, Union[str, PipelineVariable]]] = None,
+        domain: Optional[Union[str, PipelineVariable]] = None,
+        sample_payload_url: Optional[Union[str, PipelineVariable]] = None,
+        task: Optional[Union[str, PipelineVariable]] = None,
+        framework: Optional[Union[str, PipelineVariable]] = None,
+        framework_version: Optional[Union[str, PipelineVariable]] = None,
+        nearest_model_name: Optional[Union[str, PipelineVariable]] = None,
+        data_input_configuration: Optional[Union[str, PipelineVariable]] = None,
     ):
         """Creates a model package for creating SageMaker models or listing on Marketplace.
 
@@ -308,6 +318,18 @@ class PipelineModel(object):
                 metadata properties (default: None).
             domain (str): Domain values can be "COMPUTER_VISION", "NATURAL_LANGUAGE_PROCESSING",
                 "MACHINE_LEARNING" (default: None).
+            sample_payload_url (str): The S3 path where the sample payload is stored
+                (default: None).
+            task (str): Task values which are supported by Inference Recommender are "FILL_MASK",
+                "IMAGE_CLASSIFICATION", "OBJECT_DETECTION", "TEXT_GENERATION", "IMAGE_SEGMENTATION",
+                "CLASSIFICATION", "REGRESSION", "OTHER" (default: None).
+            framework (str): Machine learning framework of the model package container image
+                (default: None).
+            framework_version (str): Framework version of the Model Package Container Image
+                (default: None).
+            nearest_model_name (str): Name of a pre-trained machine learning benchmarked by
+                Amazon SageMaker Inference Recommender (default: None).
+            data_input_configuration (str): Input object for the model (default: None).
 
         Returns:
             A `sagemaker.model.ModelPackage` instance.
@@ -319,6 +341,13 @@ class PipelineModel(object):
             container_def = self.pipeline_container_def(
                 inference_instances[0] if inference_instances else None
             )
+            container_def = update_container_with_inference_params(
+                framework=framework,
+                framework_version=framework_version,
+                nearest_model_name=nearest_model_name,
+                data_input_configuration=data_input_configuration,
+                container_list=container_def,
+            )
         else:
             container_def = [
                 {
@@ -344,6 +373,8 @@ class PipelineModel(object):
             drift_check_baselines=drift_check_baselines,
             customer_metadata_properties=customer_metadata_properties,
             domain=domain,
+            sample_payload_url=sample_payload_url,
+            task=task,
         )
 
         self.sagemaker_session.create_model_package_from_containers(**model_pkg_args)
